| ctboot | R Documentation |
Joint block bootstrap for generating probabilistic base forecasts that take into account the correlation between variables at different temporal aggregation orders (Girolimetto et al. 2023).
ctboot(model_list, boot_size, agg_order, block_size = 1, seed = NULL, ...)
model_list |
A list of |
boot_size |
The number of bootstrap replicates. |
agg_order |
Highest available sampling frequency per seasonal cycle
(max. order of temporal aggregation, |
block_size |
Block size of the bootstrap, which is typically equivalent to the forecast horizon for the most temporally aggregated series. |
seed |
An integer seed. |
... |
Additional arguments for the |
A list with two elements: the seed used to sample the
errors and a list with \text{boot\_size} matrix of size
(n\times(k^\ast+m)\text{block\_size}) matrix.
Girolimetto, D., Athanasopoulos, G., Di Fonzo, T. and Hyndman, R.J. (2023), Cross-temporal probabilistic forecast reconciliation: Methodological and practical issues. International Journal of Forecasting, 40(3), 1134-1151. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ijforecast.2023.10.003")}
Bootstrap samples:
csboot(),
teboot()
Cross-temporal framework:
ctbu(),
ctcov(),
ctlcc(),
ctmo(),
ctmvn(),
ctrec(),
ctsmp(),
cttd(),
cttools(),
iterec(),
tcsrec()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.