| new_foreco_info | R Documentation |
new_foreca_info() is the contructor for the foreca_info class, which acompany
the output from the reconciliation functions in the attribute FoReco.
This is exported for extension purposes and for expert use only.
new_foreco_info(x = list())
x |
A list of information related to the reconcilied forecasts. |
new_foreco_info(list(
framework = "Cross-sectional",
forecast_horizon = 1,
comb = "shr",
cs_n = 3,
rfun = "csrec"
))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.