This function computes the projection or the mapping matrix \(\mathbf{M}\) and \(\mathbf{G}\), respectively, such that \(\widetilde{\mathbf{y}} = \mathbf{M}\widehat{\mathbf{y}} = \mathbf{S}_{te}\mathbf{G}\widehat{\mathbf{y}}\), where \(\widetilde{\mathbf{y}}\) is the vector of the reconciled forecasts, \(\widehat{\mathbf{y}}\) is the vector of the base forecasts, \(\mathbf{S}_{te}\) is the temporal structural matrix, and \(\mathbf{M} = \mathbf{S}_{te}\mathbf{G}\). For further information regarding on the structure of these matrices, refer to Girolimetto et al. (2023).
teprojmat(agg_order, comb = "ols", res = NULL, mat = "M", tew = "sum", ...)The projection matrix \(\mathbf{M}\) (mat = "M") or
the mapping matrix \(\mathbf{G}\) (mat = "G").
Highest available sampling frequency per seasonal cycle (max. order of temporal aggregation, \(m\)), or a vector representing a subset of \(p\) factors of \(m\).
A string specifying the reconciliation method. For a complete list, see tecov.
A (\(N(k^\ast+m) \times 1\)) optional numeric vector containing the in-sample residuals or validation errors ordered from the lowest frequency to the highest frequency. This vector is used to compute come covariance matrices.
A string specifying which matrix to return:
"M" (default) for \(\mathbf{M}\) and "G" for \(\mathbf{G}\).
A string specifying the type of temporal aggregation. Options
include: "sum" (simple summation, default), "avg"
(average), "first" (first value of the period), and "last"
(last value of the period).
Arguments passed on to tecov
mseIf TRUE (default) the errors used to compute
the covariance matrix are not mean-corrected.
shrink_funShrinkage function of the covariance matrix, shrink_estim (default)
Girolimetto, D., Athanasopoulos, G., Di Fonzo, T. and Hyndman, R.J. (2024), Cross-temporal probabilistic forecast reconciliation: Methodological and practical issues. International Journal of Forecasting, 40, 3, 1134-1151. tools:::Rd_expr_doi("10.1016/j.ijforecast.2023.10.003")
Utilities:
FoReco2matrix(),
aggts(),
as_ctmatrix(),
as_tevector(),
balance_hierarchy(),
commat(),
csprojmat(),
cstools(),
ctprojmat(),
cttools(),
df2aggmat(),
lcmat(),
recoinfo(),
res2matrix(),
set_bounds(),
shrink_estim(),
shrink_oasd(),
tetools(),
unbalance_hierarchy()
# Temporal framework (annual-quarterly)
Mte <- teprojmat(agg_order = 4, comb = "ols")
Gte <- teprojmat(agg_order = 4, comb = "ols", mat = "G")
Run the code above in your browser using DataLab